@@ -15,6 +15,12 @@ func init() {
 	unix.Umask(int(Umask))
 }
 
+// findExecutableExtensions returns valid OS executable extensions, on unix it
+// can be anything.
+func findExecutableExtensions(path string) []string {
+	return []string{path}
+}
+
 // IsExecutable returns if fileInfo is executable.
 func IsExecutable(fileInfo fs.FileInfo) bool {
 	return fileInfo.Mode().Perm()&0o111 != 0
