@@ -13,6 +13,22 @@ const nativeLineEnding = "\r\n"
 
 var pathExts = strings.Split(os.Getenv("PATHEXT"), string(filepath.ListSeparator))
 
+// findExecutableExtensions returns valid OS executable extensions for the
+// provided file if it does not already have an extension. The executable
+// extensions are derived from %PathExt%.
+func findExecutableExtensions(path string) []string {
+	cmdExt := filepath.Ext(path)
+	if cmdExt != "" {
+		return []string{path}
+	}
+	result := make([]string, len(pathExts))
+	withoutSuffix := strings.TrimSuffix(path, cmdExt)
+	for i, ext := range pathExts {
+		result[i] = withoutSuffix + ext
+	}
+	return result
+}
+
 // IsExecutable checks if the file is a regular file and has an extension listed
 // in the PATHEXT environment variable as per
 // https://www.nextofwindows.com/what-is-pathext-environment-variable-in-windows.
