@@ -175,28 +175,42 @@ func (c *Config) fromIniTemplateFunc(s string) map[string]any {
 	return iniFileToMap(file)
 }
 
-func (c *Config) fromJsoncTemplateFunc(s string) any {
-	var data any
-	if err := chezmoi.FormatJSONC.Unmarshal([]byte(s), &data); err != nil {
+// fromJsonTemplateFunc parses s as JSON and returns the result. In contrast to
+// encoding/json, numbers are represented as int64s or float64s if possible.
+//
+//nolint:revive,stylecheck
+func (c *Config) fromJsonTemplateFunc(s string) any {
+	var value map[string]any
+	if err := chezmoi.FormatJSON.Unmarshal([]byte(s), &value); err != nil {
 		panic(err)
 	}
-	return data
+	return value
+}
+
+// fromJsoncTemplateFunc parses s as JSONC and returns the result. In contrast
+// to encoding/json, numbers are represented as int64s or float64s if possible.
+func (c *Config) fromJsoncTemplateFunc(s string) any {
+	var value map[string]any
+	if err := chezmoi.FormatJSONC.Unmarshal([]byte(s), &value); err != nil {
+		panic(err)
+	}
+	return value
 }
 
 func (c *Config) fromTomlTemplateFunc(s string) any {
-	var data any
-	if err := chezmoi.FormatTOML.Unmarshal([]byte(s), &data); err != nil {
+	var value map[string]any
+	if err := chezmoi.FormatTOML.Unmarshal([]byte(s), &value); err != nil {
 		panic(err)
 	}
-	return data
+	return value
 }
 
 func (c *Config) fromYamlTemplateFunc(s string) any {
-	var data any
-	if err := chezmoi.FormatYAML.Unmarshal([]byte(s), &data); err != nil {
+	var value map[string]any
+	if err := chezmoi.FormatYAML.Unmarshal([]byte(s), &value); err != nil {
 		panic(err)
 	}
-	return data
+	return value
 }
 
 func (c *Config) globTemplateFunc(pattern string) []string {
